# Lecture Automator

Lecture Automator позволяет автоматически генерировать презентации с озвучкой для каждого из слайдов. Всё, что вам нужно сделать - написать текстовый файл Markdown со специальной разметкой, а остальное за вас сделает Lecture Automator.

## Установка

С помощью pip (также необходимо установить ffmpeg и [Marp](https://github.com/marp-team/marp-cli)):
```
pip install lecture-automator
```

## Использование

### Через CLI

Для использование необходимо создать Markdown-файл с описаниями слайдов (см. [Marp](https://marp.app/#get-started)) и [управляющими конструкциями](#управляющие-конструкции):
````md
# Python

```
print('Привет, мир')
```

/speech{На этом слайде представлена простейшая программа, написанная на языке програмирования Пайтон. Эта программа просто выводит указанные слова в терминал.}

---

# Python

```
a = 2
b = 4
print(a * b)
```

/speech{А здесь представлена другая программа, которая умножается число два на число четыре.}

````

Затем для генерации необходимо использовать следующую CLI команду в терминале:
```bash
lecture-automator convert Example.md Example.mp4
```

Пример сгенерированного видео:

[Example.webm](https://user-images.githubusercontent.com/33065236/231875817-1d3aae09-2a63-4bb1-8380-8b7f024bbe45.webm)

### Через Web

Lecture Automator может развернуть небольшой сервер с веб-интерфейсом, в котором можно
описывать слайды и тут же генерировать видео с возможность его просмотра прямо в данном
веб-интерфейсе.

Для его запуска необходимо выполнить следующую команду:
```bash
lecture-automator web
```


### Управляющие конструкции 

На данный момент реализованы следующие управляющие конструкции:
- `/speech{...}` - текст для озвучивания слайда (каждый слайд должен содержать данную конструкцию). 
